@@ -30,7 +30,7 @@ class GinVPNPlugin(HttpProxyBasePlugin):
             server=GinVPN.GinSettings.server_adr
             port=GinVPN.GinSettings.server_port
         except ModuleNotFoundError:
-            print("Config Not Found, run GinConfig")
+            print("Config Not Found, Quit The Proxy and Run GinConfig")
             sys.exit()
         self.server=server
         self.port=port
